# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class LiveAutoShutdownConfiguration(object):
    @poscheck_model
    def __init__(self,
                 bytes_read_timeout_seconds=None,
                 stream_timeout_minutes=None,
                 waiting_for_first_connect_timeout_minutes=None):
        # type: (int, int, int) -> None

        self._bytes_read_timeout_seconds = None
        self._stream_timeout_minutes = None
        self._waiting_for_first_connect_timeout_minutes = None
        self.discriminator = None

        if bytes_read_timeout_seconds is not None:
            self.bytes_read_timeout_seconds = bytes_read_timeout_seconds
        if stream_timeout_minutes is not None:
            self.stream_timeout_minutes = stream_timeout_minutes
        if waiting_for_first_connect_timeout_minutes is not None:
            self.waiting_for_first_connect_timeout_minutes = waiting_for_first_connect_timeout_minutes

    @property
    def openapi_types(self):
        types = {
            'bytes_read_timeout_seconds': 'int',
            'stream_timeout_minutes': 'int',
            'waiting_for_first_connect_timeout_minutes': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'bytes_read_timeout_seconds': 'bytesReadTimeoutSeconds',
            'stream_timeout_minutes': 'streamTimeoutMinutes',
            'waiting_for_first_connect_timeout_minutes': 'waitingForFirstConnectTimeoutMinutes'
        }
        return attributes

    @property
    def bytes_read_timeout_seconds(self):
        # type: () -> int
        """Gets the bytes_read_timeout_seconds of this LiveAutoShutdownConfiguration.

        Automatically shutdown the live stream if there is no input anymore for a predefined number of seconds.

        :return: The bytes_read_timeout_seconds of this LiveAutoShutdownConfiguration.
        :rtype: int
        """
        return self._bytes_read_timeout_seconds

    @bytes_read_timeout_seconds.setter
    def bytes_read_timeout_seconds(self, bytes_read_timeout_seconds):
        # type: (int) -> None
        """Sets the bytes_read_timeout_seconds of this LiveAutoShutdownConfiguration.

        Automatically shutdown the live stream if there is no input anymore for a predefined number of seconds.

        :param bytes_read_timeout_seconds: The bytes_read_timeout_seconds of this LiveAutoShutdownConfiguration.
        :type: int
        """

        if bytes_read_timeout_seconds is not None:
            if bytes_read_timeout_seconds is not None and bytes_read_timeout_seconds < 30:
                raise ValueError("Invalid value for `bytes_read_timeout_seconds`, must be a value greater than or equal to `30`")
            if not isinstance(bytes_read_timeout_seconds, int):
                raise TypeError("Invalid type for `bytes_read_timeout_seconds`, type has to be `int`")

        self._bytes_read_timeout_seconds = bytes_read_timeout_seconds

    @property
    def stream_timeout_minutes(self):
        # type: () -> int
        """Gets the stream_timeout_minutes of this LiveAutoShutdownConfiguration.

        Automatically shutdown the live stream after a predefined runtime in minutes.

        :return: The stream_timeout_minutes of this LiveAutoShutdownConfiguration.
        :rtype: int
        """
        return self._stream_timeout_minutes

    @stream_timeout_minutes.setter
    def stream_timeout_minutes(self, stream_timeout_minutes):
        # type: (int) -> None
        """Sets the stream_timeout_minutes of this LiveAutoShutdownConfiguration.

        Automatically shutdown the live stream after a predefined runtime in minutes.

        :param stream_timeout_minutes: The stream_timeout_minutes of this LiveAutoShutdownConfiguration.
        :type: int
        """

        if stream_timeout_minutes is not None:
            if stream_timeout_minutes is not None and stream_timeout_minutes < 5:
                raise ValueError("Invalid value for `stream_timeout_minutes`, must be a value greater than or equal to `5`")
            if not isinstance(stream_timeout_minutes, int):
                raise TypeError("Invalid type for `stream_timeout_minutes`, type has to be `int`")

        self._stream_timeout_minutes = stream_timeout_minutes

    @property
    def waiting_for_first_connect_timeout_minutes(self):
        # type: () -> int
        """Gets the waiting_for_first_connect_timeout_minutes of this LiveAutoShutdownConfiguration.

        Automatically shutdown the live stream if input is never connected for a predefined number of minutes.

        :return: The waiting_for_first_connect_timeout_minutes of this LiveAutoShutdownConfiguration.
        :rtype: int
        """
        return self._waiting_for_first_connect_timeout_minutes

    @waiting_for_first_connect_timeout_minutes.setter
    def waiting_for_first_connect_timeout_minutes(self, waiting_for_first_connect_timeout_minutes):
        # type: (int) -> None
        """Sets the waiting_for_first_connect_timeout_minutes of this LiveAutoShutdownConfiguration.

        Automatically shutdown the live stream if input is never connected for a predefined number of minutes.

        :param waiting_for_first_connect_timeout_minutes: The waiting_for_first_connect_timeout_minutes of this LiveAutoShutdownConfiguration.
        :type: int
        """

        if waiting_for_first_connect_timeout_minutes is not None:
            if waiting_for_first_connect_timeout_minutes is not None and waiting_for_first_connect_timeout_minutes < 5:
                raise ValueError("Invalid value for `waiting_for_first_connect_timeout_minutes`, must be a value greater than or equal to `5`")
            if not isinstance(waiting_for_first_connect_timeout_minutes, int):
                raise TypeError("Invalid type for `waiting_for_first_connect_timeout_minutes`, type has to be `int`")

        self._waiting_for_first_connect_timeout_minutes = waiting_for_first_connect_timeout_minutes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveAutoShutdownConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class TransformSkipMode(Enum):
    NONE = "NONE"
    NORMAL = "NORMAL"
    FAST = "FAST"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.resource_type import ResourceType
import pprint
import six


class ResourceLimitContainer(object):
    @poscheck_model
    def __init__(self,
                 resource=None,
                 limits=None):
        # type: (ResourceType, list[ResourceLimit]) -> None

        self._resource = None
        self._limits = list()
        self.discriminator = None

        if resource is not None:
            self.resource = resource
        if limits is not None:
            self.limits = limits

    @property
    def openapi_types(self):
        types = {
            'resource': 'ResourceType',
            'limits': 'list[ResourceLimit]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'resource': 'resource',
            'limits': 'limits'
        }
        return attributes

    @property
    def resource(self):
        # type: () -> ResourceType
        """Gets the resource of this ResourceLimitContainer.


        :return: The resource of this ResourceLimitContainer.
        :rtype: ResourceType
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        # type: (ResourceType) -> None
        """Sets the resource of this ResourceLimitContainer.


        :param resource: The resource of this ResourceLimitContainer.
        :type: ResourceType
        """

        if resource is not None:
            if not isinstance(resource, ResourceType):
                raise TypeError("Invalid type for `resource`, type has to be `ResourceType`")

        self._resource = resource

    @property
    def limits(self):
        # type: () -> list[ResourceLimit]
        """Gets the limits of this ResourceLimitContainer.


        :return: The limits of this ResourceLimitContainer.
        :rtype: list[ResourceLimit]
        """
        return self._limits

    @limits.setter
    def limits(self, limits):
        # type: (list) -> None
        """Sets the limits of this ResourceLimitContainer.


        :param limits: The limits of this ResourceLimitContainer.
        :type: list[ResourceLimit]
        """

        if limits is not None:
            if not isinstance(limits, list):
                raise TypeError("Invalid type for `limits`, type has to be `list[ResourceLimit]`")

        self._limits = limits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceLimitContainer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.mp4.mp4_api import Mp4Api
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.mp4.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.mp4.dash_mp4_representation_list_query_params import DashMp4RepresentationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.stream_per_title_fixed_resolution_and_bitrate_settings import StreamPerTitleFixedResolutionAndBitrateSettings
import pprint
import six


class StreamPerTitleSettings(object):
    @poscheck_model
    def __init__(self,
                 fixed_resolution_and_bitrate_settings=None,
                 codec_max_bitrate_factor=None,
                 codec_bufsize_factor=None):
        # type: (StreamPerTitleFixedResolutionAndBitrateSettings, float, float) -> None

        self._fixed_resolution_and_bitrate_settings = None
        self._codec_max_bitrate_factor = None
        self._codec_bufsize_factor = None
        self.discriminator = None

        if fixed_resolution_and_bitrate_settings is not None:
            self.fixed_resolution_and_bitrate_settings = fixed_resolution_and_bitrate_settings
        if codec_max_bitrate_factor is not None:
            self.codec_max_bitrate_factor = codec_max_bitrate_factor
        if codec_bufsize_factor is not None:
            self.codec_bufsize_factor = codec_bufsize_factor

    @property
    def openapi_types(self):
        types = {
            'fixed_resolution_and_bitrate_settings': 'StreamPerTitleFixedResolutionAndBitrateSettings',
            'codec_max_bitrate_factor': 'float',
            'codec_bufsize_factor': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'fixed_resolution_and_bitrate_settings': 'fixedResolutionAndBitrateSettings',
            'codec_max_bitrate_factor': 'codecMaxBitrateFactor',
            'codec_bufsize_factor': 'codecBufsizeFactor'
        }
        return attributes

    @property
    def fixed_resolution_and_bitrate_settings(self):
        # type: () -> StreamPerTitleFixedResolutionAndBitrateSettings
        """Gets the fixed_resolution_and_bitrate_settings of this StreamPerTitleSettings.

        Settings for PER_TITLE_TEMPLATE_FIXED_RESOLUTION_AND_BITRATE mode

        :return: The fixed_resolution_and_bitrate_settings of this StreamPerTitleSettings.
        :rtype: StreamPerTitleFixedResolutionAndBitrateSettings
        """
        return self._fixed_resolution_and_bitrate_settings

    @fixed_resolution_and_bitrate_settings.setter
    def fixed_resolution_and_bitrate_settings(self, fixed_resolution_and_bitrate_settings):
        # type: (StreamPerTitleFixedResolutionAndBitrateSettings) -> None
        """Sets the fixed_resolution_and_bitrate_settings of this StreamPerTitleSettings.

        Settings for PER_TITLE_TEMPLATE_FIXED_RESOLUTION_AND_BITRATE mode

        :param fixed_resolution_and_bitrate_settings: The fixed_resolution_and_bitrate_settings of this StreamPerTitleSettings.
        :type: StreamPerTitleFixedResolutionAndBitrateSettings
        """

        if fixed_resolution_and_bitrate_settings is not None:
            if not isinstance(fixed_resolution_and_bitrate_settings, StreamPerTitleFixedResolutionAndBitrateSettings):
                raise TypeError("Invalid type for `fixed_resolution_and_bitrate_settings`, type has to be `StreamPerTitleFixedResolutionAndBitrateSettings`")

        self._fixed_resolution_and_bitrate_settings = fixed_resolution_and_bitrate_settings

    @property
    def codec_max_bitrate_factor(self):
        # type: () -> float
        """Gets the codec_max_bitrate_factor of this StreamPerTitleSettings.

        This factor is used to calculate the maxBitrate of the codec configuration for the generated representation as a multiple of the targetBitrate(generated by Per-Title algorithm). This value will take precedence over the 'codecMaxBitrateFactor' from the pertitleStartConfiguration. This value will only have an impact on streams with h264 or h265 video configurations.

        :return: The codec_max_bitrate_factor of this StreamPerTitleSettings.
        :rtype: float
        """
        return self._codec_max_bitrate_factor

    @codec_max_bitrate_factor.setter
    def codec_max_bitrate_factor(self, codec_max_bitrate_factor):
        # type: (float) -> None
        """Sets the codec_max_bitrate_factor of this StreamPerTitleSettings.

        This factor is used to calculate the maxBitrate of the codec configuration for the generated representation as a multiple of the targetBitrate(generated by Per-Title algorithm). This value will take precedence over the 'codecMaxBitrateFactor' from the pertitleStartConfiguration. This value will only have an impact on streams with h264 or h265 video configurations.

        :param codec_max_bitrate_factor: The codec_max_bitrate_factor of this StreamPerTitleSettings.
        :type: float
        """

        if codec_max_bitrate_factor is not None:
            if not isinstance(codec_max_bitrate_factor, (float, int)):
                raise TypeError("Invalid type for `codec_max_bitrate_factor`, type has to be `float`")

        self._codec_max_bitrate_factor = codec_max_bitrate_factor

    @property
    def codec_bufsize_factor(self):
        # type: () -> float
        """Gets the codec_bufsize_factor of this StreamPerTitleSettings.

        This factor is used to calculate the bufsize of the codec configuration for the generated representations as a multiple of the targetBitrate(generated by Per-Title algorithm). This value will take precedence over the 'codecBufsizeFactor' from the pertitleStartConfiguration.. This value will only have an impact on streams with h264 or h265 video configurations.

        :return: The codec_bufsize_factor of this StreamPerTitleSettings.
        :rtype: float
        """
        return self._codec_bufsize_factor

    @codec_bufsize_factor.setter
    def codec_bufsize_factor(self, codec_bufsize_factor):
        # type: (float) -> None
        """Sets the codec_bufsize_factor of this StreamPerTitleSettings.

        This factor is used to calculate the bufsize of the codec configuration for the generated representations as a multiple of the targetBitrate(generated by Per-Title algorithm). This value will take precedence over the 'codecBufsizeFactor' from the pertitleStartConfiguration.. This value will only have an impact on streams with h264 or h265 video configurations.

        :param codec_bufsize_factor: The codec_bufsize_factor of this StreamPerTitleSettings.
        :type: float
        """

        if codec_bufsize_factor is not None:
            if not isinstance(codec_bufsize_factor, (float, int)):
                raise TypeError("Invalid type for `codec_bufsize_factor`, type has to be `float`")

        self._codec_bufsize_factor = codec_bufsize_factor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamPerTitleSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.hls.media.audio.audio_api import AudioApi
from bitmovin_api_sdk.encoding.manifests.hls.media.audio.audio_media_info_list_query_params import AudioMediaInfoListQueryParams



from bitmovin_api_sdk.account.organizations.groups.tenants.tenants_api import TenantsApi
from bitmovin_api_sdk.account.organizations.groups.tenants.tenant_list_query_params import TenantListQueryParams



from bitmovin_api_sdk.encoding.encodings.streams.hdr.dolby_vision.dolby_vision_api import DolbyVisionApi
from bitmovin_api_sdk.encoding.encodings.streams.hdr.dolby_vision.dolby_vision_metadata_list_query_params import DolbyVisionMetadataListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class GoogleCloudRegion(Enum):
    US_CENTRAL_1 = "US_CENTRAL_1"
    US_EAST_1 = "US_EAST_1"
    ASIA_EAST_1 = "ASIA_EAST_1"
    EUROPE_WEST_1 = "EUROPE_WEST_1"
    US_WEST_1 = "US_WEST_1"
    ASIA_EAST_2 = "ASIA_EAST_2"
    ASIA_NORTHEAST_1 = "ASIA_NORTHEAST_1"
    ASIA_SOUTH_1 = "ASIA_SOUTH_1"
    ASIA_SOUTHEAST_1 = "ASIA_SOUTHEAST_1"
    AUSTRALIA_SOUTHEAST_1 = "AUSTRALIA_SOUTHEAST_1"
    EUROPE_NORTH_1 = "EUROPE_NORTH_1"
    EUROPE_WEST_2 = "EUROPE_WEST_2"
    EUROPE_WEST_3 = "EUROPE_WEST_3"
    EUROPE_WEST_4 = "EUROPE_WEST_4"
    NORTHAMERICA_NORTHEAST_1 = "NORTHAMERICA_NORTHEAST_1"
    SOUTHAMERICA_EAST_1 = "SOUTHAMERICA_EAST_1"
    US_EAST_4 = "US_EAST_4"
    US_WEST_2 = "US_WEST_2"
    ME_CENTRAL_2 = "ME_CENTRAL_2"



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.analytics_license_custom_data_field_labels import AnalyticsLicenseCustomDataFieldLabels
from bitmovin_api_sdk.models.analytics_license_features import AnalyticsLicenseFeatures
import pprint
import six


class AnalyticsLicense(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 created_at=None,
                 custom_data=None,
                 license_key=None,
                 name=None,
                 industry=None,
                 sub_industry=None,
                 ignore_dnt=None,
                 impressions=None,
                 max_impressions=None,
                 time_zone=None,
                 retention_time=None,
                 compressed_retention_time=None,
                 compression_available_to=None,
                 domains=None,
                 player_domains=None,
                 include_in_insights=None,
                 custom_data_field_labels=None,
                 custom_data_fields_count=None,
                 order_index=None,
                 rate_limit=None,
                 features=None,
                 plan_expired_at=None):
        # type: (string_types, datetime, dict, string_types, string_types, string_types, string_types, bool, int, int, string_types, string_types, string_types, datetime, list[AnalyticsLicenseDomain], list[string_types], bool, AnalyticsLicenseCustomDataFieldLabels, int, int, string_types, AnalyticsLicenseFeatures, datetime) -> None

        self._id = None
        self._created_at = None
        self._custom_data = None
        self._license_key = None
        self._name = None
        self._industry = None
        self._sub_industry = None
        self._ignore_dnt = None
        self._impressions = None
        self._max_impressions = None
        self._time_zone = None
        self._retention_time = None
        self._compressed_retention_time = None
        self._compression_available_to = None
        self._domains = list()
        self._player_domains = list()
        self._include_in_insights = None
        self._custom_data_field_labels = None
        self._custom_data_fields_count = None
        self._order_index = None
        self._rate_limit = None
        self._features = None
        self._plan_expired_at = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if created_at is not None:
            self.created_at = created_at
        if custom_data is not None:
            self.custom_data = custom_data
        if license_key is not None:
            self.license_key = license_key
        if name is not None:
            self.name = name
        if industry is not None:
            self.industry = industry
        if sub_industry is not None:
            self.sub_industry = sub_industry
        if ignore_dnt is not None:
            self.ignore_dnt = ignore_dnt
        if impressions is not None:
            self.impressions = impressions
        if max_impressions is not None:
            self.max_impressions = max_impressions
        if time_zone is not None:
            self.time_zone = time_zone
        if retention_time is not None:
            self.retention_time = retention_time
        if compressed_retention_time is not None:
            self.compressed_retention_time = compressed_retention_time
        if compression_available_to is not None:
            self.compression_available_to = compression_available_to
        if domains is not None:
            self.domains = domains
        if player_domains is not None:
            self.player_domains = player_domains
        if include_in_insights is not None:
            self.include_in_insights = include_in_insights
        if custom_data_field_labels is not None:
            self.custom_data_field_labels = custom_data_field_labels
        if custom_data_fields_count is not None:
            self.custom_data_fields_count = custom_data_fields_count
        if order_index is not None:
            self.order_index = order_index
        if rate_limit is not None:
            self.rate_limit = rate_limit
        if features is not None:
            self.features = features
        if plan_expired_at is not None:
            self.plan_expired_at = plan_expired_at

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'created_at': 'datetime',
            'custom_data': 'dict(str, object)',
            'license_key': 'string_types',
            'name': 'string_types',
            'industry': 'string_types',
            'sub_industry': 'string_types',
            'ignore_dnt': 'bool',
            'impressions': 'int',
            'max_impressions': 'int',
            'time_zone': 'string_types',
            'retention_time': 'string_types',
            'compressed_retention_time': 'string_types',
            'compression_available_to': 'datetime',
            'domains': 'list[AnalyticsLicenseDomain]',
            'player_domains': 'list[string_types]',
            'include_in_insights': 'bool',
            'custom_data_field_labels': 'AnalyticsLicenseCustomDataFieldLabels',
            'custom_data_fields_count': 'int',
            'order_index': 'int',
            'rate_limit': 'string_types',
            'features': 'AnalyticsLicenseFeatures',
            'plan_expired_at': 'datetime'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'created_at': 'createdAt',
            'custom_data': 'customData',
            'license_key': 'licenseKey',
            'name': 'name',
            'industry': 'industry',
            'sub_industry': 'subIndustry',
            'ignore_dnt': 'ignoreDNT',
            'impressions': 'impressions',
            'max_impressions': 'maxImpressions',
            'time_zone': 'timeZone',
            'retention_time': 'retentionTime',
            'compressed_retention_time': 'compressedRetentionTime',
            'compression_available_to': 'compressionAvailableTo',
            'domains': 'domains',
            'player_domains': 'playerDomains',
            'include_in_insights': 'includeInInsights',
            'custom_data_field_labels': 'customDataFieldLabels',
            'custom_data_fields_count': 'customDataFieldsCount',
            'order_index': 'orderIndex',
            'rate_limit': 'rateLimit',
            'features': 'features',
            'plan_expired_at': 'planExpiredAt'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this AnalyticsLicense.

        Id of the Analytics License

        :return: The id of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this AnalyticsLicense.

        Id of the Analytics License

        :param id_: The id of this AnalyticsLicense.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this AnalyticsLicense.

        Creation date of the Analytics License, returned as ISO 8601 date-time format

        :return: The created_at of this AnalyticsLicense.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this AnalyticsLicense.

        Creation date of the Analytics License, returned as ISO 8601 date-time format

        :param created_at: The created_at of this AnalyticsLicense.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def custom_data(self):
        # type: () -> dict(str, object)
        """Gets the custom_data of this AnalyticsLicense.

        User-specific meta data. This can hold anything.

        :return: The custom_data of this AnalyticsLicense.
        :rtype: dict(str, object)
        """
        return self._custom_data

    @custom_data.setter
    def custom_data(self, custom_data):
        # type: (dict) -> None
        """Sets the custom_data of this AnalyticsLicense.

        User-specific meta data. This can hold anything.

        :param custom_data: The custom_data of this AnalyticsLicense.
        :type: dict(str, object)
        """

        if custom_data is not None:
            if not isinstance(custom_data, dict):
                raise TypeError("Invalid type for `custom_data`, type has to be `dict(str, object)`")

        self._custom_data = custom_data

    @property
    def license_key(self):
        # type: () -> string_types
        """Gets the license_key of this AnalyticsLicense.

        License Key

        :return: The license_key of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._license_key

    @license_key.setter
    def license_key(self, license_key):
        # type: (string_types) -> None
        """Sets the license_key of this AnalyticsLicense.

        License Key

        :param license_key: The license_key of this AnalyticsLicense.
        :type: string_types
        """

        if license_key is not None:
            if not isinstance(license_key, string_types):
                raise TypeError("Invalid type for `license_key`, type has to be `string_types`")

        self._license_key = license_key

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this AnalyticsLicense.

        Name of the Analytics License

        :return: The name of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this AnalyticsLicense.

        Name of the Analytics License

        :param name: The name of this AnalyticsLicense.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def industry(self):
        # type: () -> string_types
        """Gets the industry of this AnalyticsLicense.

        The industry of the organization associated with the Analytics License

        :return: The industry of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._industry

    @industry.setter
    def industry(self, industry):
        # type: (string_types) -> None
        """Sets the industry of this AnalyticsLicense.

        The industry of the organization associated with the Analytics License

        :param industry: The industry of this AnalyticsLicense.
        :type: string_types
        """

        if industry is not None:
            if not isinstance(industry, string_types):
                raise TypeError("Invalid type for `industry`, type has to be `string_types`")

        self._industry = industry

    @property
    def sub_industry(self):
        # type: () -> string_types
        """Gets the sub_industry of this AnalyticsLicense.

        The subindustry of the organization associated with the Analytics License

        :return: The sub_industry of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._sub_industry

    @sub_industry.setter
    def sub_industry(self, sub_industry):
        # type: (string_types) -> None
        """Sets the sub_industry of this AnalyticsLicense.

        The subindustry of the organization associated with the Analytics License

        :param sub_industry: The sub_industry of this AnalyticsLicense.
        :type: string_types
        """

        if sub_industry is not None:
            if not isinstance(sub_industry, string_types):
                raise TypeError("Invalid type for `sub_industry`, type has to be `string_types`")

        self._sub_industry = sub_industry

    @property
    def ignore_dnt(self):
        # type: () -> bool
        """Gets the ignore_dnt of this AnalyticsLicense.

        Whether the Do Not Track request from the browser should be ignored

        :return: The ignore_dnt of this AnalyticsLicense.
        :rtype: bool
        """
        return self._ignore_dnt

    @ignore_dnt.setter
    def ignore_dnt(self, ignore_dnt):
        # type: (bool) -> None
        """Sets the ignore_dnt of this AnalyticsLicense.

        Whether the Do Not Track request from the browser should be ignored

        :param ignore_dnt: The ignore_dnt of this AnalyticsLicense.
        :type: bool
        """

        if ignore_dnt is not None:
            if not isinstance(ignore_dnt, bool):
                raise TypeError("Invalid type for `ignore_dnt`, type has to be `bool`")

        self._ignore_dnt = ignore_dnt

    @property
    def impressions(self):
        # type: () -> int
        """Gets the impressions of this AnalyticsLicense.

        Number of impressions recorded

        :return: The impressions of this AnalyticsLicense.
        :rtype: int
        """
        return self._impressions

    @impressions.setter
    def impressions(self, impressions):
        # type: (int) -> None
        """Sets the impressions of this AnalyticsLicense.

        Number of impressions recorded

        :param impressions: The impressions of this AnalyticsLicense.
        :type: int
        """

        if impressions is not None:
            if not isinstance(impressions, int):
                raise TypeError("Invalid type for `impressions`, type has to be `int`")

        self._impressions = impressions

    @property
    def max_impressions(self):
        # type: () -> int
        """Gets the max_impressions of this AnalyticsLicense.

        Maximum number of impressions

        :return: The max_impressions of this AnalyticsLicense.
        :rtype: int
        """
        return self._max_impressions

    @max_impressions.setter
    def max_impressions(self, max_impressions):
        # type: (int) -> None
        """Sets the max_impressions of this AnalyticsLicense.

        Maximum number of impressions

        :param max_impressions: The max_impressions of this AnalyticsLicense.
        :type: int
        """

        if max_impressions is not None:
            if not isinstance(max_impressions, int):
                raise TypeError("Invalid type for `max_impressions`, type has to be `int`")

        self._max_impressions = max_impressions

    @property
    def time_zone(self):
        # type: () -> string_types
        """Gets the time_zone of this AnalyticsLicense.

        The timezone of the Analytics License

        :return: The time_zone of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        # type: (string_types) -> None
        """Sets the time_zone of this AnalyticsLicense.

        The timezone of the Analytics License

        :param time_zone: The time_zone of this AnalyticsLicense.
        :type: string_types
        """

        if time_zone is not None:
            if not isinstance(time_zone, string_types):
                raise TypeError("Invalid type for `time_zone`, type has to be `string_types`")

        self._time_zone = time_zone

    @property
    def retention_time(self):
        # type: () -> string_types
        """Gets the retention_time of this AnalyticsLicense.

        Retention time of impressions, returned as ISO 8601 duration format: P(n)Y(n)M(n)DT(n)H(n)M(n)S

        :return: The retention_time of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._retention_time

    @retention_time.setter
    def retention_time(self, retention_time):
        # type: (string_types) -> None
        """Sets the retention_time of this AnalyticsLicense.

        Retention time of impressions, returned as ISO 8601 duration format: P(n)Y(n)M(n)DT(n)H(n)M(n)S

        :param retention_time: The retention_time of this AnalyticsLicense.
        :type: string_types
        """

        if retention_time is not None:
            if not isinstance(retention_time, string_types):
                raise TypeError("Invalid type for `retention_time`, type has to be `string_types`")

        self._retention_time = retention_time

    @property
    def compressed_retention_time(self):
        # type: () -> string_types
        """Gets the compressed_retention_time of this AnalyticsLicense.

        Retention time for compressed data, returned as ISO 8601 duration format: P(n)Y(n)M(n)DT(n)H(n)M(n)S

        :return: The compressed_retention_time of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._compressed_retention_time

    @compressed_retention_time.setter
    def compressed_retention_time(self, compressed_retention_time):
        # type: (string_types) -> None
        """Sets the compressed_retention_time of this AnalyticsLicense.

        Retention time for compressed data, returned as ISO 8601 duration format: P(n)Y(n)M(n)DT(n)H(n)M(n)S

        :param compressed_retention_time: The compressed_retention_time of this AnalyticsLicense.
        :type: string_types
        """

        if compressed_retention_time is not None:
            if not isinstance(compressed_retention_time, string_types):
                raise TypeError("Invalid type for `compressed_retention_time`, type has to be `string_types`")

        self._compressed_retention_time = compressed_retention_time

    @property
    def compression_available_to(self):
        # type: () -> datetime
        """Gets the compression_available_to of this AnalyticsLicense.

        The date and time up until which the compressed data is available. Returned as ISO 8601 date-time format

        :return: The compression_available_to of this AnalyticsLicense.
        :rtype: datetime
        """
        return self._compression_available_to

    @compression_available_to.setter
    def compression_available_to(self, compression_available_to):
        # type: (datetime) -> None
        """Sets the compression_available_to of this AnalyticsLicense.

        The date and time up until which the compressed data is available. Returned as ISO 8601 date-time format

        :param compression_available_to: The compression_available_to of this AnalyticsLicense.
        :type: datetime
        """

        if compression_available_to is not None:
            if not isinstance(compression_available_to, datetime):
                raise TypeError("Invalid type for `compression_available_to`, type has to be `datetime`")

        self._compression_available_to = compression_available_to

    @property
    def domains(self):
        # type: () -> list[AnalyticsLicenseDomain]
        """Gets the domains of this AnalyticsLicense.

        Whitelisted domains

        :return: The domains of this AnalyticsLicense.
        :rtype: list[AnalyticsLicenseDomain]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        # type: (list) -> None
        """Sets the domains of this AnalyticsLicense.

        Whitelisted domains

        :param domains: The domains of this AnalyticsLicense.
        :type: list[AnalyticsLicenseDomain]
        """

        if domains is not None:
            if not isinstance(domains, list):
                raise TypeError("Invalid type for `domains`, type has to be `list[AnalyticsLicenseDomain]`")

        self._domains = domains

    @property
    def player_domains(self):
        # type: () -> list[string_types]
        """Gets the player_domains of this AnalyticsLicense.

        Allowlisted player domains

        :return: The player_domains of this AnalyticsLicense.
        :rtype: list[string_types]
        """
        return self._player_domains

    @player_domains.setter
    def player_domains(self, player_domains):
        # type: (list) -> None
        """Sets the player_domains of this AnalyticsLicense.

        Allowlisted player domains

        :param player_domains: The player_domains of this AnalyticsLicense.
        :type: list[string_types]
        """

        if player_domains is not None:
            if not isinstance(player_domains, list):
                raise TypeError("Invalid type for `player_domains`, type has to be `list[string_types]`")

        self._player_domains = player_domains

    @property
    def include_in_insights(self):
        # type: () -> bool
        """Gets the include_in_insights of this AnalyticsLicense.

        Whether the data of this license should be included in the industry insights or not

        :return: The include_in_insights of this AnalyticsLicense.
        :rtype: bool
        """
        return self._include_in_insights

    @include_in_insights.setter
    def include_in_insights(self, include_in_insights):
        # type: (bool) -> None
        """Sets the include_in_insights of this AnalyticsLicense.

        Whether the data of this license should be included in the industry insights or not

        :param include_in_insights: The include_in_insights of this AnalyticsLicense.
        :type: bool
        """

        if include_in_insights is not None:
            if not isinstance(include_in_insights, bool):
                raise TypeError("Invalid type for `include_in_insights`, type has to be `bool`")

        self._include_in_insights = include_in_insights

    @property
    def custom_data_field_labels(self):
        # type: () -> AnalyticsLicenseCustomDataFieldLabels
        """Gets the custom_data_field_labels of this AnalyticsLicense.

        Labels for CustomData fields

        :return: The custom_data_field_labels of this AnalyticsLicense.
        :rtype: AnalyticsLicenseCustomDataFieldLabels
        """
        return self._custom_data_field_labels

    @custom_data_field_labels.setter
    def custom_data_field_labels(self, custom_data_field_labels):
        # type: (AnalyticsLicenseCustomDataFieldLabels) -> None
        """Sets the custom_data_field_labels of this AnalyticsLicense.

        Labels for CustomData fields

        :param custom_data_field_labels: The custom_data_field_labels of this AnalyticsLicense.
        :type: AnalyticsLicenseCustomDataFieldLabels
        """

        if custom_data_field_labels is not None:
            if not isinstance(custom_data_field_labels, AnalyticsLicenseCustomDataFieldLabels):
                raise TypeError("Invalid type for `custom_data_field_labels`, type has to be `AnalyticsLicenseCustomDataFieldLabels`")

        self._custom_data_field_labels = custom_data_field_labels

    @property
    def custom_data_fields_count(self):
        # type: () -> int
        """Gets the custom_data_fields_count of this AnalyticsLicense.

        The number of customData fields available

        :return: The custom_data_fields_count of this AnalyticsLicense.
        :rtype: int
        """
        return self._custom_data_fields_count

    @custom_data_fields_count.setter
    def custom_data_fields_count(self, custom_data_fields_count):
        # type: (int) -> None
        """Sets the custom_data_fields_count of this AnalyticsLicense.

        The number of customData fields available

        :param custom_data_fields_count: The custom_data_fields_count of this AnalyticsLicense.
        :type: int
        """

        if custom_data_fields_count is not None:
            if not isinstance(custom_data_fields_count, int):
                raise TypeError("Invalid type for `custom_data_fields_count`, type has to be `int`")

        self._custom_data_fields_count = custom_data_fields_count

    @property
    def order_index(self):
        # type: () -> int
        """Gets the order_index of this AnalyticsLicense.

        Order index of license

        :return: The order_index of this AnalyticsLicense.
        :rtype: int
        """
        return self._order_index

    @order_index.setter
    def order_index(self, order_index):
        # type: (int) -> None
        """Sets the order_index of this AnalyticsLicense.

        Order index of license

        :param order_index: The order_index of this AnalyticsLicense.
        :type: int
        """

        if order_index is not None:
            if not isinstance(order_index, int):
                raise TypeError("Invalid type for `order_index`, type has to be `int`")

        self._order_index = order_index

    @property
    def rate_limit(self):
        # type: () -> string_types
        """Gets the rate_limit of this AnalyticsLicense.

        The rate limit of this license

        :return: The rate_limit of this AnalyticsLicense.
        :rtype: string_types
        """
        return self._rate_limit

    @rate_limit.setter
    def rate_limit(self, rate_limit):
        # type: (string_types) -> None
        """Sets the rate_limit of this AnalyticsLicense.

        The rate limit of this license

        :param rate_limit: The rate_limit of this AnalyticsLicense.
        :type: string_types
        """

        if rate_limit is not None:
            if not isinstance(rate_limit, string_types):
                raise TypeError("Invalid type for `rate_limit`, type has to be `string_types`")

        self._rate_limit = rate_limit

    @property
    def features(self):
        # type: () -> AnalyticsLicenseFeatures
        """Gets the features of this AnalyticsLicense.


        :return: The features of this AnalyticsLicense.
        :rtype: AnalyticsLicenseFeatures
        """
        return self._features

    @features.setter
    def features(self, features):
        # type: (AnalyticsLicenseFeatures) -> None
        """Sets the features of this AnalyticsLicense.


        :param features: The features of this AnalyticsLicense.
        :type: AnalyticsLicenseFeatures
        """

        if features is not None:
            if not isinstance(features, AnalyticsLicenseFeatures):
                raise TypeError("Invalid type for `features`, type has to be `AnalyticsLicenseFeatures`")

        self._features = features

    @property
    def plan_expired_at(self):
        # type: () -> datetime
        """Gets the plan_expired_at of this AnalyticsLicense.

        The expiration date of the license if applicable, returned as ISO 8601 date-time format

        :return: The plan_expired_at of this AnalyticsLicense.
        :rtype: datetime
        """
        return self._plan_expired_at

    @plan_expired_at.setter
    def plan_expired_at(self, plan_expired_at):
        # type: (datetime) -> None
        """Sets the plan_expired_at of this AnalyticsLicense.

        The expiration date of the license if applicable, returned as ISO 8601 date-time format

        :param plan_expired_at: The plan_expired_at of this AnalyticsLicense.
        :type: datetime
        """

        if plan_expired_at is not None:
            if not isinstance(plan_expired_at, datetime):
                raise TypeError("Invalid type for `plan_expired_at`, type has to be `datetime`")

        self._plan_expired_at = plan_expired_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsLicense):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.aspera_input import AsperaInput
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.inputs.aspera.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.aspera.aspera_input_list_query_params import AsperaInputListQueryParams


class AsperaApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AsperaApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, aspera_input, **kwargs):
        # type: (AsperaInput, dict) -> AsperaInput
        """Create Aspera Input

        :param aspera_input: The Aspera input to be created
        :type aspera_input: AsperaInput, required
        :return: Aspera input
        :rtype: AsperaInput
        """

        return self.api_client.post(
            '/encoding/inputs/aspera',
            aspera_input,
            type=AsperaInput,
            **kwargs
        )

    def delete(self, input_id, **kwargs):
        # type: (string_types, dict) -> AsperaInput
        """Delete Aspera Input

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Id of the input
        :rtype: AsperaInput
        """

        return self.api_client.delete(
            '/encoding/inputs/aspera/{input_id}',
            path_params={'input_id': input_id},
            type=AsperaInput,
            **kwargs
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> AsperaInput
        """Aspera Input Details

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Aspera input
        :rtype: AsperaInput
        """

        return self.api_client.get(
            '/encoding/inputs/aspera/{input_id}',
            path_params={'input_id': input_id},
            type=AsperaInput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AsperaInputListQueryParams, dict) -> AsperaInput
        """List Aspera Inputs

        :param query_params: Query parameters
        :type query_params: AsperaInputListQueryParams
        :return: List of Aspera inputs
        :rtype: AsperaInput
        """

        return self.api_client.get(
            '/encoding/inputs/aspera',
            query_params=query_params,
            pagination_response=True,
            type=AsperaInput,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class Id3TagType(Enum):
    RAW = "RAW"
    FRAME_ID = "FRAME_ID"
    PLAIN_TEXT = "PLAIN_TEXT"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dolby_digital_dialogue_intelligence import DolbyDigitalDialogueIntelligence
from bitmovin_api_sdk.models.dolby_digital_loudness_control_mode import DolbyDigitalLoudnessControlMode
from bitmovin_api_sdk.models.dolby_digital_loudness_control_regulation_type import DolbyDigitalLoudnessControlRegulationType
import pprint
import six


class DolbyDigitalLoudnessControl(object):
    @poscheck_model
    def __init__(self,
                 dialnorm=None,
                 dialogue_intelligence=None,
                 mode=None,
                 peak_limit=None,
                 regulation_type=None):
        # type: (int, DolbyDigitalDialogueIntelligence, DolbyDigitalLoudnessControlMode, float, DolbyDigitalLoudnessControlRegulationType) -> None

        self._dialnorm = None
        self._dialogue_intelligence = None
        self._mode = None
        self._peak_limit = None
        self._regulation_type = None
        self.discriminator = None

        if dialnorm is not None:
            self.dialnorm = dialnorm
        if dialogue_intelligence is not None:
            self.dialogue_intelligence = dialogue_intelligence
        if mode is not None:
            self.mode = mode
        if peak_limit is not None:
            self.peak_limit = peak_limit
        if regulation_type is not None:
            self.regulation_type = regulation_type

    @property
    def openapi_types(self):
        types = {
            'dialnorm': 'int',
            'dialogue_intelligence': 'DolbyDigitalDialogueIntelligence',
            'mode': 'DolbyDigitalLoudnessControlMode',
            'peak_limit': 'float',
            'regulation_type': 'DolbyDigitalLoudnessControlRegulationType'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'dialnorm': 'dialnorm',
            'dialogue_intelligence': 'dialogueIntelligence',
            'mode': 'mode',
            'peak_limit': 'peakLimit',
            'regulation_type': 'regulationType'
        }
        return attributes

    @property
    def dialnorm(self):
        # type: () -> int
        """Gets the dialnorm of this DolbyDigitalLoudnessControl.

        Dialogue Normalization value to be set on the bitstream metadata. Required if the mode is `PASSTHROUGH`, or if the mode is `CORRECTION` and regulationType is `MANUAL`. For all other combinations dialnorm must not be set.

        :return: The dialnorm of this DolbyDigitalLoudnessControl.
        :rtype: int
        """
        return self._dialnorm

    @dialnorm.setter
    def dialnorm(self, dialnorm):
        # type: (int) -> None
        """Sets the dialnorm of this DolbyDigitalLoudnessControl.

        Dialogue Normalization value to be set on the bitstream metadata. Required if the mode is `PASSTHROUGH`, or if the mode is `CORRECTION` and regulationType is `MANUAL`. For all other combinations dialnorm must not be set.

        :param dialnorm: The dialnorm of this DolbyDigitalLoudnessControl.
        :type: int
        """

        if dialnorm is not None:
            if dialnorm is not None and dialnorm > -1:
                raise ValueError("Invalid value for `dialnorm`, must be a value less than or equal to `-1`")
            if dialnorm is not None and dialnorm < -31:
                raise ValueError("Invalid value for `dialnorm`, must be a value greater than or equal to `-31`")
            if not isinstance(dialnorm, int):
                raise TypeError("Invalid type for `dialnorm`, type has to be `int`")

        self._dialnorm = dialnorm

    @property
    def dialogue_intelligence(self):
        # type: () -> DolbyDigitalDialogueIntelligence
        """Gets the dialogue_intelligence of this DolbyDigitalLoudnessControl.

        This may only be set if the mode is `PASSTHROUGH`, or if the mode is `CORRECTION` and regulationType is `MANUAL`. For all other combinations dialogueIntelligence must not be set.

        :return: The dialogue_intelligence of this DolbyDigitalLoudnessControl.
        :rtype: DolbyDigitalDialogueIntelligence
        """
        return self._dialogue_intelligence

    @dialogue_intelligence.setter
    def dialogue_intelligence(self, dialogue_intelligence):
        # type: (DolbyDigitalDialogueIntelligence) -> None
        """Sets the dialogue_intelligence of this DolbyDigitalLoudnessControl.

        This may only be set if the mode is `PASSTHROUGH`, or if the mode is `CORRECTION` and regulationType is `MANUAL`. For all other combinations dialogueIntelligence must not be set.

        :param dialogue_intelligence: The dialogue_intelligence of this DolbyDigitalLoudnessControl.
        :type: DolbyDigitalDialogueIntelligence
        """

        if dialogue_intelligence is not None:
            if not isinstance(dialogue_intelligence, DolbyDigitalDialogueIntelligence):
                raise TypeError("Invalid type for `dialogue_intelligence`, type has to be `DolbyDigitalDialogueIntelligence`")

        self._dialogue_intelligence = dialogue_intelligence

    @property
    def mode(self):
        # type: () -> DolbyDigitalLoudnessControlMode
        """Gets the mode of this DolbyDigitalLoudnessControl.


        :return: The mode of this DolbyDigitalLoudnessControl.
        :rtype: DolbyDigitalLoudnessControlMode
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        # type: (DolbyDigitalLoudnessControlMode) -> None
        """Sets the mode of this DolbyDigitalLoudnessControl.


        :param mode: The mode of this DolbyDigitalLoudnessControl.
        :type: DolbyDigitalLoudnessControlMode
        """

        if mode is not None:
            if not isinstance(mode, DolbyDigitalLoudnessControlMode):
                raise TypeError("Invalid type for `mode`, type has to be `DolbyDigitalLoudnessControlMode`")

        self._mode = mode

    @property
    def peak_limit(self):
        # type: () -> float
        """Gets the peak_limit of this DolbyDigitalLoudnessControl.

        The peak value in dB to use for loudness correction. This may only be set if the mode is `PASSTHROUGH`, or if the mode is `CORRECTION` and regulationType is `MANUAL`. For all other combinations peakLimit must not be set.

        :return: The peak_limit of this DolbyDigitalLoudnessControl.
        :rtype: float
        """
        return self._peak_limit

    @peak_limit.setter
    def peak_limit(self, peak_limit):
        # type: (float) -> None
        """Sets the peak_limit of this DolbyDigitalLoudnessControl.

        The peak value in dB to use for loudness correction. This may only be set if the mode is `PASSTHROUGH`, or if the mode is `CORRECTION` and regulationType is `MANUAL`. For all other combinations peakLimit must not be set.

        :param peak_limit: The peak_limit of this DolbyDigitalLoudnessControl.
        :type: float
        """

        if peak_limit is not None:
            if peak_limit is not None and peak_limit > -0.1:
                raise ValueError("Invalid value for `peak_limit`, must be a value less than or equal to `-0.1`")
            if peak_limit is not None and peak_limit < -8:
                raise ValueError("Invalid value for `peak_limit`, must be a value greater than or equal to `-8`")
            if not isinstance(peak_limit, (float, int)):
                raise TypeError("Invalid type for `peak_limit`, type has to be `float`")

        self._peak_limit = peak_limit

    @property
    def regulation_type(self):
        # type: () -> DolbyDigitalLoudnessControlRegulationType
        """Gets the regulation_type of this DolbyDigitalLoudnessControl.

        This is only allowed if the mode is CORRECTION. <table> <tr><th colspan=4 align=\"left\"> Predefined values for each regulation type: </th></tr> <tr><td> Regulation Type </td><td> EBU R128 </td><td> ATSC A/85 Fixed </td><td> ATSC A/85 Agile</td></tr> <tr><td> Limit Mode </td><td> `True Peak` </td><td> `True Peak` </td><td> `True Peak` </td></tr> <tr><td> Correction Mode </td><td> `PCM Normalization` </td><td> `PCM Normalization` </td><td> `Metadata Update` </td></tr> <tr><td> Peak Limit </td><td> `–3 dBTP` </td><td> `–2 dBTP` </td><td> `N/A` </td></tr> <tr><td> Dialogue Intelligence </td><td> `Off` </td><td> `On` </td><td> `On` </td></tr> <tr><td> Meter Mode </td><td> `ITU-R BS.1770-3` </td><td> `ITU-R BS.1770-3` </td><td> `ITU-R BS.1770-3` </td></tr> <tr><td> Speech Threshold </td><td> `20` </td><td> `20` </td><td> `20` </td></tr> <tr><td> Dialogue Normalization </td><td> `-23 dB` </td><td> `-24 dB` </td><td> `Set to measured loudness` </td></tr> </table> 

        :return: The regulation_type of this DolbyDigitalLoudnessControl.
        :rtype: DolbyDigitalLoudnessControlRegulationType
        """
        return self._regulation_type

    @regulation_type.setter
    def regulation_type(self, regulation_type):
        # type: (DolbyDigitalLoudnessControlRegulationType) -> None
        """Sets the regulation_type of this DolbyDigitalLoudnessControl.

        This is only allowed if the mode is CORRECTION. <table> <tr><th colspan=4 align=\"left\"> Predefined values for each regulation type: </th></tr> <tr><td> Regulation Type </td><td> EBU R128 </td><td> ATSC A/85 Fixed </td><td> ATSC A/85 Agile</td></tr> <tr><td> Limit Mode </td><td> `True Peak` </td><td> `True Peak` </td><td> `True Peak` </td></tr> <tr><td> Correction Mode </td><td> `PCM Normalization` </td><td> `PCM Normalization` </td><td> `Metadata Update` </td></tr> <tr><td> Peak Limit </td><td> `–3 dBTP` </td><td> `–2 dBTP` </td><td> `N/A` </td></tr> <tr><td> Dialogue Intelligence </td><td> `Off` </td><td> `On` </td><td> `On` </td></tr> <tr><td> Meter Mode </td><td> `ITU-R BS.1770-3` </td><td> `ITU-R BS.1770-3` </td><td> `ITU-R BS.1770-3` </td></tr> <tr><td> Speech Threshold </td><td> `20` </td><td> `20` </td><td> `20` </td></tr> <tr><td> Dialogue Normalization </td><td> `-23 dB` </td><td> `-24 dB` </td><td> `Set to measured loudness` </td></tr> </table> 

        :param regulation_type: The regulation_type of this DolbyDigitalLoudnessControl.
        :type: DolbyDigitalLoudnessControlRegulationType
        """

        if regulation_type is not None:
            if not isinstance(regulation_type, DolbyDigitalLoudnessControlRegulationType):
                raise TypeError("Invalid type for `regulation_type`, type has to be `DolbyDigitalLoudnessControlRegulationType`")

        self._regulation_type = regulation_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyDigitalLoudnessControl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.analytics.outputs.outputs_api import OutputsApi
from bitmovin_api_sdk.analytics.outputs.azure.azure_api import AzureApi
from bitmovin_api_sdk.analytics.outputs.s3_role_based.s3_role_based_api import S3RoleBasedApi
from bitmovin_api_sdk.analytics.outputs.gcs_service_account.gcs_service_account_api import GcsServiceAccountApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SceneType(Enum):
    LOGO_IDENT = "LOGO_IDENT"
    OPENING_CREDITS = "OPENING_CREDITS"
    RECAP = "RECAP"
    PREVIEW_THIS_TITLE = "PREVIEW_THIS_TITLE"
    PROMOTION_OTHER_TITLE = "PROMOTION_OTHER_TITLE"
    BREAK_BUMPER = "BREAK_BUMPER"
    END_CREDITS = "END_CREDITS"
    ADS = "ADS"
    MAIN_CONTENT = "MAIN_CONTENT"
    UNKNOWN = "UNKNOWN"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.oci_account_region_settings import OciAccountRegionSettings
from bitmovin_api_sdk.models.oci_cloud_region import OciCloudRegion
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.infrastructure.oci.regions.oci_account_region_settings_list_query_params import OciAccountRegionSettingsListQueryParams


class RegionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(RegionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, infrastructure_id, region, oci_account_region_settings, **kwargs):
        # type: (string_types, OciCloudRegion, OciAccountRegionSettings, dict) -> OciAccountRegionSettings
        """Add OCI account region settings

        :param infrastructure_id: Id of the OCI account
        :type infrastructure_id: string_types, required
        :param region: OCI region
        :type region: OciCloudRegion, required
        :param oci_account_region_settings: The OCI account region settings to be added
        :type oci_account_region_settings: OciAccountRegionSettings, required
        :return: OCI account region settings
        :rtype: OciAccountRegionSettings
        """

        return self.api_client.post(
            '/encoding/infrastructure/oci/{infrastructure_id}/regions/{region}',
            oci_account_region_settings,
            path_params={'infrastructure_id': infrastructure_id, 'region': region},
            type=OciAccountRegionSettings,
            **kwargs
        )

    def delete(self, infrastructure_id, region, **kwargs):
        # type: (string_types, OciCloudRegion, dict) -> OciAccountRegionSettings
        """Delete OCI account region settings

        :param infrastructure_id: Id of the OCI account
        :type infrastructure_id: string_types, required
        :param region: OCI region
        :type region: OciCloudRegion, required
        :return: OCI account region settings
        :rtype: OciAccountRegionSettings
        """

        return self.api_client.delete(
            '/encoding/infrastructure/oci/{infrastructure_id}/regions/{region}',
            path_params={'infrastructure_id': infrastructure_id, 'region': region},
            type=OciAccountRegionSettings,
            **kwargs
        )

    def get(self, infrastructure_id, region, **kwargs):
        # type: (string_types, OciCloudRegion, dict) -> OciAccountRegionSettings
        """OCI account region settings details

        :param infrastructure_id: Id of the OCI account
        :type infrastructure_id: string_types, required
        :param region: OCI region
        :type region: OciCloudRegion, required
        :return: Region settings for specified region
        :rtype: OciAccountRegionSettings
        """

        return self.api_client.get(
            '/encoding/infrastructure/oci/{infrastructure_id}/regions/{region}',
            path_params={'infrastructure_id': infrastructure_id, 'region': region},
            type=OciAccountRegionSettings,
            **kwargs
        )

    def list(self, infrastructure_id, query_params=None, **kwargs):
        # type: (string_types, OciAccountRegionSettingsListQueryParams, dict) -> OciAccountRegionSettings
        """List OCI account region settings

        :param infrastructure_id: Id of the OCI account
        :type infrastructure_id: string_types, required
        :param query_params: Query parameters
        :type query_params: OciAccountRegionSettingsListQueryParams
        :return: List of OCI account region settings
        :rtype: OciAccountRegionSettings
        """

        return self.api_client.get(
            '/encoding/infrastructure/oci/{infrastructure_id}/regions',
            path_params={'infrastructure_id': infrastructure_id},
            query_params=query_params,
            pagination_response=True,
            type=OciAccountRegionSettings,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AesEncryptionMethod(Enum):
    SAMPLE_AES = "SAMPLE_AES"
    AES_128 = "AES_128"



class LiveEncodingStatsEventListQueryParams(object):
    def __init__(self, offset=None, limit=None, sort_by_time=None):
        # type: (int, int, bool) -> None
        super(LiveEncodingStatsEventListQueryParams, self).__init__()

        self.offset = offset
        self.limit = limit
        self.sort_by_time = sort_by_time

    @property
    def openapi_types(self):
        types = {
            'offset': 'int',
            'limit': 'int',
            'sort_by_time': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'offset': 'offset',
            'limit': 'limit',
            'sort_by_time': 'sortByTime'
        }

        return attributes



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AkamaiCloudRegion(Enum):
    BR_GRU = "BR_GRU"
    ES_MAD = "ES_MAD"
    FR_PAR = "FR_PAR"
    ID_CGK = "ID_CGK"
    IN_MAA = "IN_MAA"
    IT_MIL = "IT_MIL"
    JP_OSA = "JP_OSA"
    NL_AMS = "NL_AMS"
    SE_STO = "SE_STO"
    US_LAX = "US_LAX"
    US_MIA = "US_MIA"
    US_ORD = "US_ORD"
    US_SEA = "US_SEA"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DashScte35PeriodOption(Enum):
    SINGLE_PERIOD = "SINGLE_PERIOD"
    MULTI_PERIOD = "MULTI_PERIOD"



from bitmovin_api_sdk.encoding.encodings.streams.watermarking.watermarking_api import WatermarkingApi
from bitmovin_api_sdk.encoding.encodings.streams.watermarking.nexguard_file_marker.nexguard_file_marker_api import NexguardFileMarkerApi



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.analytics.outputs.azure.azure_api import AzureApi
from bitmovin_api_sdk.analytics.outputs.s3_role_based.s3_role_based_api import S3RoleBasedApi
from bitmovin_api_sdk.analytics.outputs.gcs_service_account.gcs_service_account_api import GcsServiceAccountApi


class OutputsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(OutputsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.azure = AzureApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.s3_role_based = S3RoleBasedApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.gcs_service_account = GcsServiceAccountApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.scene_analysis_details_response import SceneAnalysisDetailsResponse
from bitmovin_api_sdk.ai_scene_analysis.analyses.by_encoding_id.details.language.language_api import LanguageApi


class DetailsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DetailsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.language = LanguageApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> SceneAnalysisDetailsResponse
        """Get AI scene analysis details by encoding ID

        :param encoding_id: The encoding ID
        :type encoding_id: string_types, required
        :return:
        :rtype: SceneAnalysisDetailsResponse
        """

        return self.api_client.get(
            '/ai-scene-analysis/analyses/by-encoding-id/{encoding_id}/details',
            path_params={'encoding_id': encoding_id},
            type=SceneAnalysisDetailsResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.backup_srt_inputs import BackupSrtInputs
from bitmovin_api_sdk.models.input import Input
from bitmovin_api_sdk.models.srt_mode import SrtMode
import pprint
import six


class SrtInput(Input):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 mode=None,
                 host=None,
                 port=None,
                 path=None,
                 latency=None,
                 passphrase=None,
                 key_length=None,
                 backup_srt_inputs=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, SrtMode, string_types, int, string_types, int, string_types, int, BackupSrtInputs) -> None
        super(SrtInput, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._mode = None
        self._host = None
        self._port = None
        self._path = None
        self._latency = None
        self._passphrase = None
        self._key_length = None
        self._backup_srt_inputs = None
        self.discriminator = None

        if mode is not None:
            self.mode = mode
        if host is not None:
            self.host = host
        if port is not None:
            self.port = port
        if path is not None:
            self.path = path
        if latency is not None:
            self.latency = latency
        if passphrase is not None:
            self.passphrase = passphrase
        if key_length is not None:
            self.key_length = key_length
        if backup_srt_inputs is not None:
            self.backup_srt_inputs = backup_srt_inputs

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(SrtInput, self), 'openapi_types'):
            types = getattr(super(SrtInput, self), 'openapi_types')

        types.update({
            'mode': 'SrtMode',
            'host': 'string_types',
            'port': 'int',
            'path': 'string_types',
            'latency': 'int',
            'passphrase': 'string_types',
            'key_length': 'int',
            'backup_srt_inputs': 'BackupSrtInputs'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(SrtInput, self), 'attribute_map'):
            attributes = getattr(super(SrtInput, self), 'attribute_map')

        attributes.update({
            'mode': 'mode',
            'host': 'host',
            'port': 'port',
            'path': 'path',
            'latency': 'latency',
            'passphrase': 'passphrase',
            'key_length': 'keyLength',
            'backup_srt_inputs': 'backupSrtInputs'
        })
        return attributes

    @property
    def mode(self):
        # type: () -> SrtMode
        """Gets the mode of this SrtInput.

        The SRT mode to use (required)

        :return: The mode of this SrtInput.
        :rtype: SrtMode
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        # type: (SrtMode) -> None
        """Sets the mode of this SrtInput.

        The SRT mode to use (required)

        :param mode: The mode of this SrtInput.
        :type: SrtMode
        """

        if mode is not None:
            if not isinstance(mode, SrtMode):
                raise TypeError("Invalid type for `mode`, type has to be `SrtMode`")

        self._mode = mode

    @property
    def host(self):
        # type: () -> string_types
        """Gets the host of this SrtInput.

        The name or IP of the host providing the SRT stream (only used in CALLER mode)

        :return: The host of this SrtInput.
        :rtype: string_types
        """
        return self._host

    @host.setter
    def host(self, host):
        # type: (string_types) -> None
        """Sets the host of this SrtInput.

        The name or IP of the host providing the SRT stream (only used in CALLER mode)

        :param host: The host of this SrtInput.
        :type: string_types
        """

        if host is not None:
            if not isinstance(host, string_types):
                raise TypeError("Invalid type for `host`, type has to be `string_types`")

        self._host = host

    @property
    def port(self):
        # type: () -> int
        """Gets the port of this SrtInput.

        The port to connect to or listen on. Has to be one of [2088, 2089, 2090, 2091] when using LISTENER mode. (required)

        :return: The port of this SrtInput.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        # type: (int) -> None
        """Sets the port of this SrtInput.

        The port to connect to or listen on. Has to be one of [2088, 2089, 2090, 2091] when using LISTENER mode. (required)

        :param port: The port of this SrtInput.
        :type: int
        """

        if port is not None:
            if not isinstance(port, int):
                raise TypeError("Invalid type for `port`, type has to be `int`")

        self._port = port

    @property
    def path(self):
        # type: () -> string_types
        """Gets the path of this SrtInput.

        The path parameter of the SRT stream

        :return: The path of this SrtInput.
        :rtype: string_types
        """
        return self._path

    @path.setter
    def path(self, path):
        # type: (string_types) -> None
        """Sets the path of this SrtInput.

        The path parameter of the SRT stream

        :param path: The path of this SrtInput.
        :type: string_types
        """

        if path is not None:
            if not isinstance(path, string_types):
                raise TypeError("Invalid type for `path`, type has to be `string_types`")

        self._path = path

    @property
    def latency(self):
        # type: () -> int
        """Gets the latency of this SrtInput.

        The maximum accepted transmission latency in milliseconds (when both parties set different values, the maximum of the two is used for both)

        :return: The latency of this SrtInput.
        :rtype: int
        """
        return self._latency

    @latency.setter
    def latency(self, latency):
        # type: (int) -> None
        """Sets the latency of this SrtInput.

        The maximum accepted transmission latency in milliseconds (when both parties set different values, the maximum of the two is used for both)

        :param latency: The latency of this SrtInput.
        :type: int
        """

        if latency is not None:
            if not isinstance(latency, int):
                raise TypeError("Invalid type for `latency`, type has to be `int`")

        self._latency = latency

    @property
    def passphrase(self):
        # type: () -> string_types
        """Gets the passphrase of this SrtInput.

        The passphrase used to secure the SRT stream. For AES-128 encryption, you must enter a 16-character passphrase; for AES-256, you must enter a 32-character passphrase

        :return: The passphrase of this SrtInput.
        :rtype: string_types
        """
        return self._passphrase

    @passphrase.setter
    def passphrase(self, passphrase):
        # type: (string_types) -> None
        """Sets the passphrase of this SrtInput.

        The passphrase used to secure the SRT stream. For AES-128 encryption, you must enter a 16-character passphrase; for AES-256, you must enter a 32-character passphrase

        :param passphrase: The passphrase of this SrtInput.
        :type: string_types
        """

        if passphrase is not None:
            if not isinstance(passphrase, string_types):
                raise TypeError("Invalid type for `passphrase`, type has to be `string_types`")

        self._passphrase = passphrase

    @property
    def key_length(self):
        # type: () -> int
        """Gets the key_length of this SrtInput.

        The type of AES encryption determines the length of the key (passphrase). AES-128 uses a 16-character (128-bit) passphrase, and AES-256 uses a 32-character (256-bit) passphrase.

        :return: The key_length of this SrtInput.
        :rtype: int
        """
        return self._key_length

    @key_length.setter
    def key_length(self, key_length):
        # type: (int) -> None
        """Sets the key_length of this SrtInput.

        The type of AES encryption determines the length of the key (passphrase). AES-128 uses a 16-character (128-bit) passphrase, and AES-256 uses a 32-character (256-bit) passphrase.

        :param key_length: The key_length of this SrtInput.
        :type: int
        """

        if key_length is not None:
            if not isinstance(key_length, int):
                raise TypeError("Invalid type for `key_length`, type has to be `int`")

        self._key_length = key_length

    @property
    def backup_srt_inputs(self):
        # type: () -> BackupSrtInputs
        """Gets the backup_srt_inputs of this SrtInput.


        :return: The backup_srt_inputs of this SrtInput.
        :rtype: BackupSrtInputs
        """
        return self._backup_srt_inputs

    @backup_srt_inputs.setter
    def backup_srt_inputs(self, backup_srt_inputs):
        # type: (BackupSrtInputs) -> None
        """Sets the backup_srt_inputs of this SrtInput.


        :param backup_srt_inputs: The backup_srt_inputs of this SrtInput.
        :type: BackupSrtInputs
        """

        if backup_srt_inputs is not None:
            if not isinstance(backup_srt_inputs, BackupSrtInputs):
                raise TypeError("Invalid type for `backup_srt_inputs`, type has to be `BackupSrtInputs`")

        self._backup_srt_inputs = backup_srt_inputs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(SrtInput, self), "to_dict"):
            result = super(SrtInput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SrtInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.infrastructure.azure.azure_api import AzureApi
from bitmovin_api_sdk.encoding.infrastructure.azure.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.azure.azure_account_list_query_params import AzureAccountListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class H264SubMe(Enum):
    FULLPEL = "FULLPEL"
    SAD = "SAD"
    SATD = "SATD"
    QPEL3 = "QPEL3"
    QPEL4 = "QPEL4"
    QPEL5 = "QPEL5"
    RD_IP = "RD_IP"
    RD_ALL = "RD_ALL"
    RD_REF_IP = "RD_REF_IP"
    RD_REF_ALL = "RD_REF_ALL"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class OciCloudRegion(Enum):
    EU_FRANKFURT_1 = "EU_FRANKFURT_1"
    US_ASHBURN_1 = "US_ASHBURN_1"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PrewarmedEncoderPoolAction(Enum):
    START = "START"
    STOP = "STOP"



from bitmovin_api_sdk.encoding.statistics.encodings.live.options.options_api import OptionsApi
from bitmovin_api_sdk.encoding.statistics.encodings.live.options.live_options_statistics_list_by_date_range_query_params import LiveOptionsStatisticsListByDateRangeQueryParams
